Enum Class DiagnosticOption

java.lang.Object
java.lang.Enum<DiagnosticOption>
org.refcodes.runtime.DiagnosticOption
All Implemented Interfaces:
Serializable, Comparable<DiagnosticOption>, Constable, DescriptionAccessor, EnvironmentVariableNameAccessor, NameAccessor, SystemPropertyNameAccessor, TypeAccessor, org.refcodes.ontology.EnumTerm, org.refcodes.ontology.Term, org.refcodes.ontology.UnsafeConcept, org.refcodes.ontology.UnsafeTaxon, Option, Setting

public enum DiagnosticOption extends Enum<DiagnosticOption> implements Option
The DiagnosticOption enumeration defines known options supported by the DiagnosticOptions class.
  • Enum Constant Details

    • DIAGNOSTICS_LIMIT

      public static final DiagnosticOption DIAGNOSTICS_LIMIT
      Key identifying a limit option.

      The associated value is expected to be an Integer. Its semantic meaning (for example, limiting the number of repeated elements rendered in a schema) is defined by the Schemable implementation consuming this option.

  • Method Details

    • values

      public static DiagnosticOption[] values()
      Returns an array containing the constants of this enum class, in the order they are declared.
      Returns:
      an array containing the constants of this enum class, in the order they are declared
    • valueOf

      public static DiagnosticOption valueOf(String name)
      Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum class has no constant with the specified name
      NullPointerException - if the argument is null
    • getDescription

      public String getDescription()
      Specified by:
      getDescription in interface DescriptionAccessor
    • getType

      public Class<Integer> getType()
      Specified by:
      getType in interface TypeAccessor