Class DiagnosticOptions.Builder
java.lang.Object
org.refcodes.ontology.Taxonomy.Builder
org.refcodes.runtime.Settings.Builder
org.refcodes.runtime.Options.Builder
org.refcodes.runtime.DiagnosticOptions.Builder
- Enclosing class:
DiagnosticOptions
Builder for creating
DiagnosticOptions instances.
The builder follows the fluent builder pattern and allows incremental construction of option sets.
-
Field Summary
Fields inherited from class org.refcodes.ontology.Taxonomy.Builder
properties -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbuild()withLimit(int aLimit) Sets theDiagnosticOption.DIAGNOSTICS_LIMIToption.withProperties(Map<String, Object> aProperties) withProperty(Enum aKey, Object aValue) withProperty(String aKey, Object aValue) withProperty(org.refcodes.ontology.Taxon<T> aKey, T aValue) Methods inherited from class org.refcodes.ontology.Taxonomy.Builder
withProperty
-
Constructor Details
-
Builder
public Builder()
-
-
Method Details
-
withProperty
- Overrides:
withPropertyin classOptions.Builder
-
withProperty
- Overrides:
withPropertyin classOptions.Builder
-
withProperties
- Overrides:
withPropertiesin classOptions.Builder
-
withProperty
- Overrides:
withPropertyin classOptions.Builder
-
withLimit
Sets the
DiagnosticOption.DIAGNOSTICS_LIMIToption.The semantic interpretation of the limit value is defined by the
Schemableimplementation consuming the resultingDiagnosticOptions.- Parameters:
aLimit- the limit value to set- Returns:
- Returns this builder instance as of the builder pattern.
-
build
- Overrides:
buildin classOptions.Builder
-