Class DumpBuilder

java.lang.Object
org.refcodes.runtime.DumpBuilder
All Implemented Interfaces:
org.refcodes.mixin.ObjectAccessor, org.refcodes.mixin.ObjectAccessor.ObjectBuilder<DumpBuilder>, org.refcodes.mixin.ObjectAccessor.ObjectMutator, org.refcodes.mixin.ObjectAccessor.ObjectProperty

public class DumpBuilder extends Object implements org.refcodes.mixin.ObjectAccessor.ObjectProperty, org.refcodes.mixin.ObjectAccessor.ObjectBuilder<DumpBuilder>
The DumpBuilder assists you in inspecting the content of an object. Creates a Map containing the dump of an object's the member variable's values, the names being the keys and the values being the member variables' values.