Enum Class NativeImageCode
- All Implemented Interfaces:
Serializable,Comparable<NativeImageCode>,Constable,org.refcodes.mixin.ValueAccessor<String>
public enum NativeImageCode
extends Enum<NativeImageCode>
implements org.refcodes.mixin.ValueAccessor<String>
Defines the values of the
SystemProperty.NATIVE_IMAGE_CODE system
property.-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>>Nested classes/interfaces inherited from interface org.refcodes.mixin.ValueAccessor
org.refcodes.mixin.ValueAccessor.ValueBuilder<V,B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V, B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V>, org.refcodes.mixin.ValueAccessor.ValueProperty<V> -
Enum Constant Summary
Enum ConstantsEnum ConstantDescriptionIf the propertySystemProperty.NATIVE_IMAGE_CODEreturnsBUILDTIMEthe code is executing at image runtime.If the propertySystemProperty.NATIVE_IMAGE_CODEreturnsRUNTIMEthe code is executing in the context of image building (e.g. in a static initializer of a class that will be contained in the image). -
Method Summary
Modifier and TypeMethodDescriptiongetValue()static booleanDetermines whether we are invoked upon buildtime (???)static booleanDetermines whether we are inside an executing native image, e.g. theSystemProperty.NATIVE_IMAGE_CODE's value evaluates toRUNTIME's value.static NativeImageCodeReturns the enum constant of this class with the specified name.static NativeImageCode[]values()Returns an array containing the constants of this enum class, in the order they are declared.Methods inherited from class java.lang.Enum
clone, compareTo, describeConstable, equals, finalize, getDeclaringClass, hashCode, name, ordinal, toString, valueOfMethods inherited from interface org.refcodes.mixin.ValueAccessor
getValueOr, hasValue
-
Enum Constant Details
-
RUNTIME
If the propertySystemProperty.NATIVE_IMAGE_CODEreturnsRUNTIMEthe code is executing in the context of image building (e.g. in a static initializer of a class that will be contained in the image). -
BUILDTIME
If the propertySystemProperty.NATIVE_IMAGE_CODEreturnsBUILDTIMEthe code is executing at image runtime.
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-
getValue
-
isRuntime
public static boolean isRuntime()Determines whether we are inside an executing native image, e.g. theSystemProperty.NATIVE_IMAGE_CODE's value evaluates toRUNTIME's value.- Returns:
- True in case we are inside an executing native image.
-
isBuildtime
public static boolean isBuildtime()Determines whether we are invoked upon buildtime (???), e.g. theSystemProperty.NATIVE_IMAGE_CODE's value evaluates toBUILDTIME's value.- Returns:
- True in case we are invoked upon buildtime (???).
-