- All Implemented Interfaces:
Serializable,Comparable<NativeImageKind>,Constable,org.refcodes.mixin.ValueAccessor<String>
public enum NativeImageKind
extends Enum<NativeImageKind>
implements org.refcodes.mixin.ValueAccessor<String>
Defines the values of the
SystemProperty.NATIVE_IMAGE_KIND system
property.-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>>Nested classes/interfaces inherited from interface org.refcodes.mixin.ValueAccessor
org.refcodes.mixin.ValueAccessor.ValueBuilder<V extends Object,B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V, B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V extends Object>, org.refcodes.mixin.ValueAccessor.ValueProperty<V extends Object> -
Enum Constant Summary
Enum ConstantsEnum ConstantDescriptionIf the propertySystemProperty.NATIVE_IMAGE_KINDisExecutablethe image is built as an executable.If the propertySystemProperty.NATIVE_IMAGE_KINDisSHARED_LIBRARYthe image is built as a shared library. -
Method Summary
Modifier and TypeMethodDescriptiongetValue()static booleanDetermines whether we have an executable native image, e.g. theSystemProperty.NATIVE_IMAGE_KIND's value evaluates toEXECUTABLE's value.static booleanDetermines whether we have a shared library, e.g. theSystemProperty.NATIVE_IMAGE_KIND's value evaluates toSHARED_LIBRARY's value.static NativeImageKindReturns the enum constant of this class with the specified name.static NativeImageKind[]values()Returns an array containing the constants of this enum class, in the order they are declared.Methods inherited from class java.lang.Enum
clone, compareTo, describeConstable, equals, finalize, getDeclaringClass, hashCode, name, ordinal, toString, valueOfMethods inherited from interface org.refcodes.mixin.ValueAccessor
getValueOr
-
Enum Constant Details
-
EXECUTABLE
If the propertySystemProperty.NATIVE_IMAGE_KINDisExecutablethe image is built as an executable. -
SHARED_LIBRARY
If the propertySystemProperty.NATIVE_IMAGE_KINDisSHARED_LIBRARYthe image is built as a shared library.
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-
getValue
- Specified by:
getValuein interfaceorg.refcodes.mixin.ValueAccessor<String>
-
isExecutable
public static boolean isExecutable()Determines whether we have an executable native image, e.g. theSystemProperty.NATIVE_IMAGE_KIND's value evaluates toEXECUTABLE's value.- Returns:
- True in case we have an executable native image.
-