Enum Class OptionsSchemaOntology

java.lang.Object
java.lang.Enum<OptionsSchemaOntology>
org.refcodes.runtime.OptionsSchemaOntology
All Implemented Interfaces:
Serializable, Comparable<OptionsSchemaOntology>, Constable, DescriptionAccessor, NameAccessor, TypeAccessor, org.refcodes.ontology.EnumTerm, org.refcodes.ontology.Term, org.refcodes.ontology.UnsafeConcept

public enum OptionsSchemaOntology extends Enum<OptionsSchemaOntology> implements org.refcodes.ontology.UnsafeConcept
The OptionsSchemaOntology describes the terms used for Schema generation of the Options type.
  • Enum Constant Details

    • SYSTEM_PROPERTY_NAME

      public static final OptionsSchemaOntology SYSTEM_PROPERTY_NAME
      The name of the associated JVM system property.
    • SYSTEM_PROPERTY_VALUE

      public static final OptionsSchemaOntology SYSTEM_PROPERTY_VALUE
      The value of the according JVM system property.
    • ENVIRONMENT_VARIABLE_NAME

      public static final OptionsSchemaOntology ENVIRONMENT_VARIABLE_NAME
      The name of the associated environment variable.
    • ENVIRONMENT_VARIABLE_VALUE

      public static final OptionsSchemaOntology ENVIRONMENT_VARIABLE_VALUE
      The value of the according environment variable.
    • PROVIDED_NAME

      public static final OptionsSchemaOntology PROVIDED_NAME
      The given (programmatically provided) name.
    • PROVIDED_VALUE

      public static final OptionsSchemaOntology PROVIDED_VALUE
      The given (programmatically provided) value.
    • VALUE_SOURCE

      public static final OptionsSchemaOntology VALUE_SOURCE
      The source of the value.
  • Method Details

    • values

      public static OptionsSchemaOntology[] values()
      Returns an array containing the constants of this enum class, in the order they are declared.
      Returns:
      an array containing the constants of this enum class, in the order they are declared
    • valueOf

      public static OptionsSchemaOntology valueOf(String name)
      Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum class has no constant with the specified name
      NullPointerException - if the argument is null
    • getType

      public Class getType()
      Specified by:
      getType in interface TypeAccessor
    • getDescription

      public String getDescription()
      Specified by:
      getDescription in interface DescriptionAccessor