Class PropertyBuilderImpl

java.lang.Object
org.refcodes.runtime.PropertyBuilderImpl
All Implemented Interfaces:
org.refcodes.mixin.KeyAccessor<String>, org.refcodes.mixin.KeyAccessor.KeyBuilder<String,​PropertyBuilder>, org.refcodes.mixin.KeyAccessor.KeyMutator<String>, org.refcodes.mixin.KeyAccessor.KeyProperty<String>, PropertyBuilder

public class PropertyBuilderImpl
extends Object
implements PropertyBuilder
The Class PropertyBuilderImpl.
  • Constructor Details

    • PropertyBuilderImpl

      public PropertyBuilderImpl()
  • Method Details

    • getKey

      public String getKey()
      Specified by:
      getKey in interface org.refcodes.mixin.KeyAccessor<String>
    • setKey

      public void setKey​(String aKey)
      Specified by:
      setKey in interface org.refcodes.mixin.KeyAccessor.KeyMutator<String>
    • withKey

      public PropertyBuilder withKey​(String aKey)
      Specified by:
      withKey in interface org.refcodes.mixin.KeyAccessor.KeyBuilder<String,​PropertyBuilder>
    • toPath

      public String toPath​(String aKey)
      Converts the provided key as of KeyAccessor.getKey() to a path (as of PathMap). A path begins with a path delimiter "/" (as of Delimiter.PATH and with all non alphanumeric digits being replaced by the path delimiter. Any non alphanumeric sequence is truncated to a single path delimiter.
      Specified by:
      toPath in interface PropertyBuilder
      Parameters:
      aKey - The key to be converted.
      Returns:
      The path representation of the according key.
    • toSystemProperty

      public String toSystemProperty​(String aKey)
      Converts the provided key to a system property. A system property is the camel-case version of the according key.
      Specified by:
      toSystemProperty in interface PropertyBuilder
      Parameters:
      aKey - The key to be converted.
      Returns:
      The camel-case representation of the according key.
    • toEnvironmentVariable

      public String toEnvironmentVariable​(String aKey)
      Converts the provided key to an environment variable. An environment variable is the upper-case snake-case version of the according key.
      Specified by:
      toEnvironmentVariable in interface PropertyBuilder
      Parameters:
      aKey - The key to be converted.
      Returns:
      The upper-case snake-case representation of the according key.
    • getSystemProperty

      public String getSystemProperty​(String aKey)
      Returns the according system's property after having converted the provided key to a system property. A system property is the camel-case version of the according key.
      Specified by:
      getSystemProperty in interface PropertyBuilder
      Parameters:
      aKey - The value of the key to be converted.
      Returns:
      The system's property of the camel-case representation of the according key.
    • getEnvironmentVariable

      public String getEnvironmentVariable​(String aKey)
      Returns the according environment variable after having converted the provided key to an environment variable. An environment variable is the upper-case snake-case version of the according key.
      Specified by:
      getEnvironmentVariable in interface PropertyBuilder
      Parameters:
      aKey - The value of the key to be converted.
      Returns:
      The environment variable of the upper-case snake-case representation of the according key.