Enum Class Shell

java.lang.Object
java.lang.Enum<Shell>
org.refcodes.runtime.Shell
All Implemented Interfaces:
Serializable, Comparable<Shell>, Constable, org.refcodes.mixin.DetectedAccessor

public enum Shell extends Enum<Shell> implements org.refcodes.mixin.DetectedAccessor
Enumeration with the (relevant) shells (command line interpreters).
  • Nested Class Summary

    Nested classes/interfaces inherited from class java.lang.Enum

    Enum.EnumDesc<E extends Enum<E>>

    Nested classes/interfaces inherited from interface org.refcodes.mixin.DetectedAccessor

    org.refcodes.mixin.DetectedAccessor.DetectedBuilder<B extends org.refcodes.mixin.DetectedAccessor.DetectedBuilder<B>>, org.refcodes.mixin.DetectedAccessor.DetectedMutator, org.refcodes.mixin.DetectedAccessor.DetectedProperty
  • Enum Constant Summary

    Enum Constants
    Enum Constant
    Description
     
    MS Windows PowerShell:.
    Unix / Linux / BSD like shell.
     
    MS Windows WIN_CMD.EXE
  • Method Summary

    Modifier and Type
    Method
    Description
    boolean
    Determines whether this enumeration represents the current Shell (e.g. this Shell has be detected to be running your application).
    static Shell
    Tries to determine the command line interpreter (CLI) - if any - this process is running in, e.g. whether we are running in a DOS console environment or a Linux alike Shell.
    static Shell
    Returns the enum constant of this class with the specified name.
    static Shell[]
    Returns an array containing the constants of this enum class, in the order they are declared.

    Methods inherited from class java.lang.Object

    getClass, notify, notifyAll, wait, wait, wait
  • Enum Constant Details

    • SHELL

      public static final Shell SHELL
      Unix / Linux / BSD like shell.
    • WIN_CMD

      public static final Shell WIN_CMD
      MS Windows WIN_CMD.EXE
    • POWER_SHELL

      public static final Shell POWER_SHELL
      MS Windows PowerShell:.
    • NONE

      public static final Shell NONE
    • UNKNOWN

      public static final Shell UNKNOWN
  • Method Details

    • values

      public static Shell[] values()
      Returns an array containing the constants of this enum class, in the order they are declared.
      Returns:
      an array containing the constants of this enum class, in the order they are declared
    • valueOf

      public static Shell valueOf(String name)
      Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum class has no constant with the specified name
      NullPointerException - if the argument is null
    • toShell

      public static Shell toShell()
      Tries to determine the command line interpreter (CLI) - if any - this process is running in, e.g. whether we are running in a DOS console environment or a Linux alike Shell.
      Returns:
      The CLI type, in case we are in a DOS / WIN_CMD console environment, WIN_CMD is returned (for example).
    • isDetected

      public boolean isDetected()
      Determines whether this enumeration represents the current Shell (e.g. this Shell has be detected to be running your application).
      Specified by:
      isDetected in interface org.refcodes.mixin.DetectedAccessor
      Returns:
      True in case this enumeration (most probably) represents this session's Shell.