Enum Class SystemContext

java.lang.Object
java.lang.Enum<SystemContext>
org.refcodes.runtime.SystemContext
All Implemented Interfaces:
Serializable, Comparable<SystemContext>, Constable

public enum SystemContext extends Enum<SystemContext>
Describes the context within a system's environment regarding host, user and application contexts as well as the currently invoked Java runtime session.