Uses of Enum Class
org.refcodes.runtime.ConfigLocator
-
Uses of ConfigLocator in org.refcodes.runtime
Subclasses with type arguments of type ConfigLocator in org.refcodes.runtimeModifier and TypeClassDescriptionenumThis enumeration represents configuration folder locations (of typeFile) and configuration file retrieval as of the chosen configuration mode.Methods in org.refcodes.runtime that return ConfigLocatorModifier and TypeMethodDescriptionstatic ConfigLocatorReturns the enum constant of this class with the specified name.static ConfigLocator[]ConfigLocator.values()Returns an array containing the constants of this enum class, in the order they are declared.