Uses of Class
org.refcodes.runtime.Configuration
-
Uses of Configuration in org.refcodes.runtime
Classes in org.refcodes.runtime that implement interfaces with type arguments of type ConfigurationModifier and TypeClassDescriptionclassConverts a key to the format of a system property (camel-case) or an environment variable (snake-case in upper-case).Methods in org.refcodes.runtime that return Configuration