The Options class serves as a generic information container for
providing arbitrary, optional parameters and interfaces with the runtime
environment: The Options container provides flexible, extensible
configuration lookup with support for explicit values, JVM system properties,
and environment variables.