Uses of Enum Class
org.refcodes.runtime.DiagnosticOption
-
Uses of DiagnosticOption in org.refcodes.runtime
Subclasses with type arguments of type DiagnosticOption in org.refcodes.runtimeModifier and TypeClassDescriptionenumTheDiagnosticOptionenumeration defines known options supported by theDiagnosticOptionsclass.Methods in org.refcodes.runtime that return DiagnosticOptionModifier and TypeMethodDescriptionstatic DiagnosticOptionReturns the enum constant of this class with the specified name.static DiagnosticOption[]DiagnosticOption.values()Returns an array containing the constants of this enum class, in the order they are declared.