Uses of Enum Class
org.refcodes.runtime.DiagnosticOptions.Configuration
-
Uses of DiagnosticOptions.Configuration in org.refcodes.runtime
Subclasses with type arguments of type DiagnosticOptions.Configuration in org.refcodes.runtimeModifier and TypeClassDescriptionstatic enumTheDiagnosticOptions.Configurationenumeration defines known options supported by this class.Methods in org.refcodes.runtime that return DiagnosticOptions.ConfigurationModifier and TypeMethodDescriptionReturns the enum constant of this class with the specified name.static DiagnosticOptions.Configuration[]DiagnosticOptions.Configuration.values()Returns an array containing the constants of this enum class, in the order they are declared.