Uses of Enum Class
org.refcodes.runtime.EnvironmentVariable
-
Uses of EnvironmentVariable in org.refcodes.runtime
Methods in org.refcodes.runtime that return EnvironmentVariableModifier and TypeMethodDescriptionstatic EnvironmentVariableReturns the enum constant of this class with the specified name.static EnvironmentVariable[]EnvironmentVariable.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in org.refcodes.runtime with parameters of type EnvironmentVariableModifier and TypeMethodDescriptionstatic StringSystemProperty.toPropertyValue(String aDefaultValue, SystemProperty aSystemProperty, EnvironmentVariable... aEnvironmentProperties) Gets the value for the provided properties, if non was found then the default value is taken.static StringSystemProperty.toPropertyValue(SystemProperty aSystemProperty, EnvironmentVariable... aEnvironmentProperties) Gets the value for the provided properties, if non was found then null is returned.