Uses of Enum Class
org.refcodes.runtime.NativeImageCode
-
Uses of NativeImageCode in org.refcodes.runtime
Subclasses with type arguments of type NativeImageCode in org.refcodes.runtimeModifier and TypeClassDescriptionenumDefines the values of theSystemProperty.NATIVE_IMAGE_CODEsystem property.Methods in org.refcodes.runtime that return NativeImageCodeModifier and TypeMethodDescriptionstatic NativeImageCodeReturns the enum constant of this class with the specified name.static NativeImageCode[]NativeImageCode.values()Returns an array containing the constants of this enum class, in the order they are declared.