Uses of Enum Class
org.refcodes.runtime.NativeImageKind
-
Uses of NativeImageKind in org.refcodes.runtime
Methods in org.refcodes.runtime that return NativeImageKindModifier and TypeMethodDescriptionstatic NativeImageKindReturns the enum constant of this class with the specified name.static NativeImageKind[]NativeImageKind.values()Returns an array containing the constants of this enum class, in the order they are declared.