Uses of Enum Class
org.refcodes.runtime.OperatingSystem
-
Uses of OperatingSystem in org.refcodes.runtime
Subclasses with type arguments of type OperatingSystem in org.refcodes.runtimeModifier and TypeClassDescriptionenumEnumeration with the (supported) operating systems.Methods in org.refcodes.runtime that return OperatingSystemModifier and TypeMethodDescriptionstatic OperatingSystemOperatingSystem.toOperatingSystem()Determines the operating system your application is currently running on.static OperatingSystemReturns the enum constant of this class with the specified name.static OperatingSystem[]OperatingSystem.values()Returns an array containing the constants of this enum class, in the order they are declared.