Uses of Enum Class
org.refcodes.runtime.OptionsSchemaOntology
-
Uses of OptionsSchemaOntology in org.refcodes.runtime
Subclasses with type arguments of type OptionsSchemaOntology in org.refcodes.runtimeModifier and TypeClassDescriptionenumMethods in org.refcodes.runtime that return OptionsSchemaOntologyModifier and TypeMethodDescriptionstatic OptionsSchemaOntologyReturns the enum constant of this class with the specified name.static OptionsSchemaOntology[]OptionsSchemaOntology.values()Returns an array containing the constants of this enum class, in the order they are declared.