Uses of Enum Class
org.refcodes.runtime.OptionsSchemaOntology.ValueSource
-
Uses of OptionsSchemaOntology.ValueSource in org.refcodes.runtime
Subclasses with type arguments of type OptionsSchemaOntology.ValueSource in org.refcodes.runtimeMethods in org.refcodes.runtime that return OptionsSchemaOntology.ValueSourceModifier and TypeMethodDescriptionReturns the enum constant of this class with the specified name.static OptionsSchemaOntology.ValueSource[]OptionsSchemaOntology.ValueSource.values()Returns an array containing the constants of this enum class, in the order they are declared.