Uses of Class
org.refcodes.runtime.Settings
-
Uses of Settings in org.refcodes.runtime
Subclasses of Settings in org.refcodes.runtimeModifier and TypeClassDescriptionclassTheDiagnosticOptionsrepresent a set of options influencing how aDiagnosableinstance renders its runtime diagnosticsSchema.classTheOptionsclass serves as a generic information container for providing arbitrary, optional parameters and interfaces with the runtime environment: TheOptionscontainer provides flexible, extensible configuration lookup with support for explicit values, JVM system properties, and environment variables.Methods in org.refcodes.runtime that return SettingsModifier and TypeMethodDescriptionSettings.Builder.build()protected SettingsSettings.createResult()Settings.fromNamespace(String aNamespace) Settings.merge(org.refcodes.ontology.Taxonomy aOther) Settings.ofNamespace(String aNamespace) Settings.removeNamespace(String aNamespace) Settings.transformKeys(Function<String, String> aMapper) Settings.transformValues(Function<Object, Object> aMapper)