Uses of Enum Class
org.refcodes.runtime.SystemContext
-
Uses of SystemContext in org.refcodes.runtime
Subclasses with type arguments of type SystemContext in org.refcodes.runtimeModifier and TypeClassDescriptionenumDescribes the context within a system's environment regarding host, user and application contexts as well as the currently invoked Java runtime session.Methods in org.refcodes.runtime that return SystemContextModifier and TypeMethodDescriptionstatic SystemContextReturns the enum constant of this class with the specified name.static SystemContext[]SystemContext.values()Returns an array containing the constants of this enum class, in the order they are declared.