Uses of Enum Class
org.refcodes.runtime.SystemProperty
-
Uses of SystemProperty in org.refcodes.runtime
Subclasses with type arguments of type SystemProperty in org.refcodes.runtimeMethods in org.refcodes.runtime that return SystemPropertyModifier and TypeMethodDescriptionstatic SystemPropertyReturns the enum constant of this class with the specified name.static SystemProperty[]SystemProperty.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in org.refcodes.runtime with parameters of type SystemPropertyModifier and TypeMethodDescriptionstatic StringSystemProperty.toPropertyValue(String aDefaultValue, SystemProperty aSystemProperty, EnvironmentVariable... aEnvironmentProperties) Gets the value for the provided properties, if non was found then the default value is taken.static StringSystemProperty.toPropertyValue(SystemProperty aSystemProperty, EnvironmentVariable... aEnvironmentProperties) Gets the value for the provided properties, if non was found then null is returned.