Uses of Enum Class
org.refcodes.runtime.Terminal.CharSetCapability
-
Uses of Terminal.CharSetCapability in org.refcodes.runtime
Subclasses with type arguments of type Terminal.CharSetCapability in org.refcodes.runtimeModifier and TypeClassDescriptionstatic enumTheTerminal.CharSetCapabilitydefines three categories of character capabilities as observed on various platform.Methods in org.refcodes.runtime that return Terminal.CharSetCapabilityModifier and TypeMethodDescriptionstatic Terminal.CharSetCapabilityTerminal.toCharSetCapability()Determines theTerminal.CharSetCapabilityof the current terminal session.static Terminal.CharSetCapabilityReturns the enum constant of this class with the specified name.static Terminal.CharSetCapability[]Terminal.CharSetCapability.values()Returns an array containing the constants of this enum class, in the order they are declared.