The Correlation assigns an according (as of the enumeration)
Correlation-TID to the invoking process, this TID is used in log files and is
part of the process's request or response pay-load in order to track process
execution throughout a JVM.
The Diagnosable mixin provides means for a data structure to describe
itself as a diagnostic report generating a Schema hierarchy
configured by (optional) Options.
The Option type extends the Setting type and describes
enumerations representing well known and normalized (hierarchical)
configuration options for subclasses of the Options container.
The Options class serves as a generic information container for
providing arbitrary, optional parameters and interfaces with the runtime
environment: The Options container provides flexible, extensible
configuration lookup with support for explicit values, JVM system properties,
and environment variables.
Describes the context within a system's environment regarding host, user and
application contexts as well as the currently invoked Java runtime session.