org.refcodes.mixin.ObjectAccessor, org.refcodes.mixin.ObjectAccessor.ObjectBuilder<DumpBuilder>, org.refcodes.mixin.ObjectAccessor.ObjectMutator, org.refcodes.mixin.ObjectAccessor.ObjectPropertyDumpBuilderImplpublic interface DumpBuilder extends org.refcodes.mixin.ObjectAccessor.ObjectProperty, org.refcodes.mixin.ObjectAccessor.ObjectBuilder<DumpBuilder>
DumpBuilder assists you in inspecting the content of an object.
Creates a Map containing the dump of an object's the member
variable's values, the names being the keys and the values being the member
variables' values.| Modifier and Type | Method | Description |
|---|---|---|
static DumpBuilder |
build() |
This is a convenience method for easily instantiating the according
builder.
|
default Map<String,String> |
toDump() |
Dumps the state of the contained object (as of
ObjectAccessor.ObjectMutator.setObject(Object)) into a Map which is returned as
result. |
Map<String,String> |
toDump(Object aObj) |
Dumps the state of the provided object into a
Map which is
returned as result. |
default Map<String,String> toDump()
ObjectAccessor.ObjectMutator.setObject(Object)) into a Map which is returned as
result.Map with the dumped properties of the implementing
instance.Map<String,String> toDump(Object aObj)
Map which is
returned as result.aObj - The object for which to create the dump.Map with the dumped properties of the implementing
instance.static DumpBuilder build()
Copyright © 2021. All rights reserved.