Package org.refcodes.runtime
Class DumpBuilderImpl
- java.lang.Object
-
- org.refcodes.runtime.DumpBuilderImpl
-
- All Implemented Interfaces:
org.refcodes.mixin.ObjectAccessor,org.refcodes.mixin.ObjectAccessor.ObjectBuilder<DumpBuilder>,org.refcodes.mixin.ObjectAccessor.ObjectMutator,org.refcodes.mixin.ObjectAccessor.ObjectProperty,DumpBuilder
public class DumpBuilderImpl extends Object implements DumpBuilder
Extend thetoDump(Object, Map)wit aListif visited objects and a "nested"-counter and dig recursively into the object. Use theDelimiter.PATH("/") delimiter to conform with theCanonicalMap's Properties subclass (as of refcodes-configuration artifact).
-
-
Constructor Summary
Constructors Constructor Description DumpBuilderImpl()
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description ObjectgetObject()voidsetObject(Object aObject)Map<String,String>toDump(Object aObj)Dumps the state of the provided object into aMapwhich is returned as result.protected static Map<String,String>toDump(Object aObj, Map<String,String> aDump)Dumps the state of the implementing instance into the providedMapwhich is returned as result.DumpBuilderwithObject(Object aObject)-
Methods inherited from interface org.refcodes.runtime.DumpBuilder
build, toDump
-
-
-
-
Method Detail
-
getObject
public Object getObject()
- Specified by:
getObjectin interfaceorg.refcodes.mixin.ObjectAccessor
-
setObject
public void setObject(Object aObject)
- Specified by:
setObjectin interfaceorg.refcodes.mixin.ObjectAccessor.ObjectMutator
-
withObject
public DumpBuilder withObject(Object aObject)
- Specified by:
withObjectin interfaceorg.refcodes.mixin.ObjectAccessor.ObjectBuilder<DumpBuilder>
-
toDump
public Map<String,String> toDump(Object aObj)
Dumps the state of the provided object into aMapwhich is returned as result.- Specified by:
toDumpin interfaceDumpBuilder- Parameters:
aObj- The object for which to create the dump.- Returns:
- The
Mapwith the dumped properties of the implementing instance.
-
toDump
protected static Map<String,String> toDump(Object aObj, Map<String,String> aDump)
Dumps the state of the implementing instance into the providedMapwhich is returned as result. This default implementation uses reflection to create a basic dump.Mapproperties are processed but not recursively digged into. Existing properties are overwritten in case shadowing super-class's properties.
-
-