Package org.refcodes.runtime
Interface SessionCorrelation<B extends SessionCorrelation<B>>
-
- Type Parameters:
B- The builder to return in order to be able to apply multiple build operations.
public interface SessionCorrelation<B extends SessionCorrelation<B>>Provides methods to set Session-Correlation behavior: When enabled viasetSessionCorrelation(boolean)(or the like), then an existing Session-Correlation-ID might be forwarded by setting it into theCorrelationsingleton viaCorrelation.SESSION'sCorrelation.setId(String). When being disabled, then no Session-Correlation handling will be done, any existingCorrelation.SESSION'sCorrelation.getId()may stay untouched!
-
-
Method Summary
All Methods Instance Methods Abstract Methods Default Methods Modifier and Type Method Description default voiddisableSessionCorrelation()Disables the automatic Session-Correlation mechanism.default voidenableSessionCorrelation()Enables the automatic Session-Correlation mechanism.booleanhasSessionCorrelation()Determines whether Session-Correlation is being enabled or disabled.voidsetSessionCorrelation(boolean hasSessionCorrelation)Enables or disables the automatic Session-Correlation mechanism.BwithDisableSessionCorrelation()Builder method for thedisableSessionCorrelation()operation.BwithEnableSessionCorrelation()Builder method for theenableSessionCorrelation()operation.BwithSessionCorrelation(boolean hasSessionCorrelation)Builder method for thesetSessionCorrelation(boolean)operation.
-
-
-
Method Detail
-
setSessionCorrelation
void setSessionCorrelation(boolean hasSessionCorrelation)
Enables or disables the automatic Session-Correlation mechanism.- Parameters:
hasSessionCorrelation- When true then Session-Correlation is enabled, else disabled.
-
withSessionCorrelation
B withSessionCorrelation(boolean hasSessionCorrelation)
Builder method for thesetSessionCorrelation(boolean)operation.- Parameters:
hasSessionCorrelation- When true then Session-Correlation is enabled, else disabled.- Returns:
- The builder for applying multiple build operations.
-
enableSessionCorrelation
default void enableSessionCorrelation()
Enables the automatic Session-Correlation mechanism.
-
withEnableSessionCorrelation
B withEnableSessionCorrelation()
Builder method for theenableSessionCorrelation()operation.- Returns:
- The builder for applying multiple build operations.
-
disableSessionCorrelation
default void disableSessionCorrelation()
Disables the automatic Session-Correlation mechanism.
-
withDisableSessionCorrelation
B withDisableSessionCorrelation()
Builder method for thedisableSessionCorrelation()operation.- Returns:
- The builder for applying multiple build operations.
-
hasSessionCorrelation
boolean hasSessionCorrelation()
Determines whether Session-Correlation is being enabled or disabled.- Returns:
- True in case Session-Correlation is being enabled, else false.
-
-