Serializable, Comparable<Shell>public enum Shell extends Enum<Shell>
| Enum Constant | Description |
|---|---|
NONE |
|
POWER_SHELL |
MS Windows PowerShell:.
|
SHELL |
Unix / Linux / BSD like shell.
|
UNKNOWN |
|
WIN_CMD |
MS Windows WIN_CMD.EXE
|
| Modifier and Type | Method | Description |
|---|---|---|
static Shell |
toShell() |
Tries to determine the command line interpreter (CLI) - if any - this
process is running in, e.g. whether we are running in a DOS console
environment or a Linux alike Shell.
|
static Shell |
valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static Shell[] |
values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final Shell SHELL
public static final Shell WIN_CMD
public static final Shell POWER_SHELL
public static final Shell NONE
public static final Shell UNKNOWN
public static Shell[] values()
for (Shell c : Shell.values()) System.out.println(c);
public static Shell valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic static Shell toShell()
WIN_CMD is returned (for example).Copyright © 2018. All rights reserved.