| ConfigLocator |
This enumeration represents configuration folder locations (of type
File) and configuration file retrieval as of the chosen configuration
mode.
|
| Correlation |
The Correlation assigns an according (as of the enumeration)
Correlation-ID to the invoking process, this ID is used in log files and is
part of the process's request or response pay-load in order to track process
execution throughout a JVM.
|
| DumpBuilder |
The DumpBuilder assists you in inspecting the content of an object.
|
| OperatingSystem |
Enumeration with the (supported) operating systems.
|
| PropertyBuilder |
Converts a key to the format of a system property (camel-case) or an
environment variable (snake-case in upper-case).
|
| ReflectionUtility.NonExistingValueClass |
This class indicates a non existing value in the name-to-value mapping.
|
| RequestCorrelation |
|
| SessionCorrelation |
|
| Shell |
Enumeration with the (relevant) shells (command line interpreters).
|
| SystemContext |
Describes the context within a system's environment regarding host, user and
application contexts as well as the currently invoked Java runtime session.
|
| Terminal |
Enumeration with the (relevant) terminals as well as interpolated terminal
metrics.
|