All Classes and Interfaces
Class
Description
This utility class provides method useful for the refcodes-cli artifact and
whose implementation has been motivated by the implementation of the
refcodes-cli artifact.
This enumeration represents configuration folder locations (of type
File) and configuration file retrieval as of the chosen configuration
mode.The
Correlation assigns an according (as of the enumeration)
Correlation-TID to the invoking process, this TID is used in log files and is
part of the process's request or response pay-load in order to track process
execution throughout a JVM.The
Diagnosable mixin provides means for a data structure to describe
itself as a diagnostic report generating a Schema hierarchy
configured by (optional) Options.The
DiagnosticOptions represent a set of options influencing how a
Diagnosable instance renders its runtime diagnostics Schema.Builder for creating
DiagnosticOptions instances.The
DiagnosticOptions.Configuration enumeration defines known options supported by
this class.EnvironmentVariable for retrieving some common environment variables
with ease.Utility for acquiring runtime information on software systems, classes or
objects.
This class indicates a non existing value in the name-to-value mapping.
The
Host type abstracts the computer system on which this application
runs on.Defines the values of the
SystemProperty.NATIVE_IMAGE_CODE system
property.Defines the values of the
SystemProperty.NATIVE_IMAGE_KIND system
property.Enumeration with the (supported) operating systems.
The
OptionDescriptor interface describes enumerations representing
well known configuration options for subclasses of the Options class.The
Options class serves as a generic information container for
providing arbitrary, optional parameters and interfaces with the runtime
environment: The Options container provides flexible, extensible
configuration lookup with support for explicit values, JVM system properties,
and environment variables.Builder for creating
Options instances.The purpose of a
OptionsSchema is automatically generate diagnostics
insights of DiagnosticOptions type.Builder for creating
OptionsSchema instances.Enumeration with the (relevant) shells (command line interpreters).
Describes the context within a system's environment regarding host, user and
application contexts as well as the currently invoked Java runtime session.
SystemProperty define values to be used at runtime.Enumeration with the (relevant) terminals as well as interpolated terminal
metrics.
The
Terminal.CharSetCapability defines three categories of character
capabilities as observed on various platform.