Interface Diagnosable
- All Superinterfaces:
org.refcodes.schema.Schemable<DiagnosticOptions>
- All Known Implementing Classes:
DiagnosticOptions,Options
The
Diagnosable mixin provides means for a data structure to describe
itself as a diagnostic report generating a Schema hierarchy
configured by (optional) Options.-
Method Summary
Methods inherited from interface org.refcodes.schema.Schemable
toSchema, toSchema