Enum Class DiagnosticOption
- All Implemented Interfaces:
Serializable, Comparable<DiagnosticOption>, Constable, DescriptionAccessor, EnvironmentVariableNameAccessor, NameAccessor, SystemPropertyNameAccessor, TypeAccessor, org.refcodes.ontology.EnumTerm, org.refcodes.ontology.Term, org.refcodes.ontology.UnsafeConcept, org.refcodes.ontology.UnsafeTaxon, Option, Setting
The
DiagnosticOption enumeration defines known options supported by
the DiagnosticOptions class.-
Nested Class Summary
Nested classes/interfaces inherited from class Enum
Enum.EnumDesc<E>Nested classes/interfaces inherited from interface DescriptionAccessor
DescriptionAccessor.DescriptionBuilder<B>, DescriptionAccessor.DescriptionMutator, DescriptionAccessor.DescriptionPropertyNested classes/interfaces inherited from interface EnvironmentVariableNameAccessor
EnvironmentVariableNameAccessor.EnvironmentVariableNameBuilder<B>, EnvironmentVariableNameAccessor.EnvironmentVariableNameMutator, EnvironmentVariableNameAccessor.EnvironmentVariableNamePropertyNested classes/interfaces inherited from interface NameAccessor
NameAccessor.NameBuilder<B>, NameAccessor.NameMutator, NameAccessor.NamePropertyNested classes/interfaces inherited from interface SystemPropertyNameAccessor
SystemPropertyNameAccessor.SystemPropertyNameBuilder<B>, SystemPropertyNameAccessor.SystemPropertyNameMutator, SystemPropertyNameAccessor.SystemPropertyNamePropertyNested classes/interfaces inherited from interface TypeAccessor
TypeAccessor.TypeBuilder<T,B>, TypeAccessor.TypeMutator<T>, TypeAccessor.TypeProperty<T> -
Enum Constant Summary
Enum Constants -
Method Summary
Modifier and TypeMethodDescriptiongetType()static DiagnosticOptionReturns the enum constant of this class with the specified name.static DiagnosticOption[]values()Returns an array containing the constants of this enum class, in the order they are declared.Methods inherited from class Enum
clone, compareTo, describeConstable, equals, finalize, getDeclaringClass, hashCode, name, ordinal, toString, valueOfMethods inherited from interface Option
getEnvironmentVariableName, getSystemPropertyNameMethods inherited from interface org.refcodes.ontology.UnsafeConcept
get, getOr, putMethods inherited from interface org.refcodes.ontology.UnsafeTaxon
getName, name
-
Enum Constant Details
-
DIAGNOSTICS_LIMIT
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-
getDescription
- Specified by:
getDescriptionin interfaceDescriptionAccessor
-
getType
- Specified by:
getTypein interfaceTypeAccessor
-