Enum Class DiagnosticOptions.Configuration
java.lang.Object
java.lang.Enum<DiagnosticOptions.Configuration>
org.refcodes.runtime.DiagnosticOptions.Configuration
- All Implemented Interfaces:
Serializable,Comparable<DiagnosticOptions.Configuration>,Constable,org.refcodes.mixin.DescriptionAccessor,org.refcodes.mixin.EnvironmentVariableNameAccessor,org.refcodes.mixin.SystemPropertyNameAccessor,org.refcodes.mixin.TypeAccessor,OptionDescriptor
- Enclosing class:
DiagnosticOptions
public static enum DiagnosticOptions.Configuration
extends Enum<DiagnosticOptions.Configuration>
implements OptionDescriptor
The
DiagnosticOptions.Configuration enumeration defines known options supported by
this class.-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>>Nested classes/interfaces inherited from interface org.refcodes.mixin.DescriptionAccessor
org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B extends org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B>>, org.refcodes.mixin.DescriptionAccessor.DescriptionMutator, org.refcodes.mixin.DescriptionAccessor.DescriptionPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.EnvironmentVariableNameAccessor
org.refcodes.mixin.EnvironmentVariableNameAccessor.EnvironmentVariableNameBuilder<B extends org.refcodes.mixin.EnvironmentVariableNameAccessor.EnvironmentVariableNameBuilder<B>>, org.refcodes.mixin.EnvironmentVariableNameAccessor.EnvironmentVariableNameMutator, org.refcodes.mixin.EnvironmentVariableNameAccessor.EnvironmentVariableNamePropertyNested classes/interfaces inherited from interface org.refcodes.mixin.SystemPropertyNameAccessor
org.refcodes.mixin.SystemPropertyNameAccessor.SystemPropertyNameBuilder<B extends org.refcodes.mixin.SystemPropertyNameAccessor.SystemPropertyNameBuilder<B>>, org.refcodes.mixin.SystemPropertyNameAccessor.SystemPropertyNameMutator, org.refcodes.mixin.SystemPropertyNameAccessor.SystemPropertyNamePropertyNested classes/interfaces inherited from interface org.refcodes.mixin.TypeAccessor
org.refcodes.mixin.TypeAccessor.TypeBuilder<T,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T, B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T>, org.refcodes.mixin.TypeAccessor.TypeProperty<T> -
Enum Constant Summary
Enum Constants -
Method Summary
Modifier and TypeMethodDescriptionClass<?> getType()Returns the enum constant of this class with the specified name.static DiagnosticOptions.Configuration[]values()Returns an array containing the constants of this enum class, in the order they are declared.Methods inherited from class java.lang.Enum
clone, compareTo, describeConstable, equals, finalize, getDeclaringClass, hashCode, name, ordinal, toString, valueOfMethods inherited from interface org.refcodes.runtime.OptionDescriptor
getEnvironmentVariableName, getSystemPropertyName
-
Enum Constant Details
-
DIAGNOSTICS_LIMIT
Key identifying a limit option.
The associated value is expected to be an
Integer. Its semantic meaning (for example, limiting the number of repeated elements rendered in a schema) is defined by theSchemableimplementation consuming this option.
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-
getDescription
- Specified by:
getDescriptionin interfaceorg.refcodes.mixin.DescriptionAccessor
-
getType
- Specified by:
getTypein interfaceorg.refcodes.mixin.TypeAccessor
-