Interface DumpBuilder

All Superinterfaces:
org.refcodes.mixin.ObjectAccessor, org.refcodes.mixin.ObjectAccessor.ObjectBuilder<DumpBuilder>, org.refcodes.mixin.ObjectAccessor.ObjectMutator, org.refcodes.mixin.ObjectAccessor.ObjectProperty
All Known Implementing Classes:
DumpBuilderImpl

public interface DumpBuilder
extends org.refcodes.mixin.ObjectAccessor.ObjectProperty, org.refcodes.mixin.ObjectAccessor.ObjectBuilder<DumpBuilder>
The DumpBuilder assists you in inspecting the content of an object. Creates a Map containing the dump of an object's the member variable's values, the names being the keys and the values being the member variables' values.
  • Nested Class Summary

    Nested classes/interfaces inherited from interface org.refcodes.mixin.ObjectAccessor

    org.refcodes.mixin.ObjectAccessor.ObjectBuilder<B extends org.refcodes.mixin.ObjectAccessor.ObjectBuilder<B>>, org.refcodes.mixin.ObjectAccessor.ObjectMutator, org.refcodes.mixin.ObjectAccessor.ObjectProperty
  • Method Summary

    Modifier and Type Method Description
    static DumpBuilder build()
    This is a convenience method for easily instantiating the according builder.
    default Map<String,​String> toDump()
    Dumps the state of the contained object (as of ObjectAccessor.ObjectMutator.setObject(Object)) into a Map which is returned as result.
    Map<String,​String> toDump​(Object aObj)
    Dumps the state of the provided object into a Map which is returned as result.

    Methods inherited from interface org.refcodes.mixin.ObjectAccessor

    getObject

    Methods inherited from interface org.refcodes.mixin.ObjectAccessor.ObjectBuilder

    withObject

    Methods inherited from interface org.refcodes.mixin.ObjectAccessor.ObjectMutator

    setObject

    Methods inherited from interface org.refcodes.mixin.ObjectAccessor.ObjectProperty

    letObject
  • Method Details

    • toDump

      default Map<String,​String> toDump()
      Dumps the state of the contained object (as of ObjectAccessor.ObjectMutator.setObject(Object)) into a Map which is returned as result.
      Returns:
      The Map with the dumped properties of the implementing instance.
    • toDump

      Map<String,​String> toDump​(Object aObj)
      Dumps the state of the provided object into a Map which is returned as result.
      Parameters:
      aObj - The object for which to create the dump.
      Returns:
      The Map with the dumped properties of the implementing instance.
    • build

      static DumpBuilder build()
      This is a convenience method for easily instantiating the according builder.
      Returns:
      an instance (using a default implementation) of this builder