Class IdentifierUtility
java.lang.Object
org.refcodes.runtime.IdentifierUtility
Utility class addressing various identifier related issues.
-
Method Summary
Modifier and TypeMethodDescriptionstatic StringtoNormalized(String aText, char aSeparator) Normalizes the provided text by removing all non-alphanumeric and non-numeric prefixed and suffixed characters, adding a separator whenever lower case characters are followed by upper case characters and by converting multiple succeeding separators to a single separator and by converting all upper case characters to lower case.
-
Method Details
-
toNormalized
Normalizes the provided text by removing all non-alphanumeric and non-numeric prefixed and suffixed characters, adding a separator whenever lower case characters are followed by upper case characters and by converting multiple succeeding separators to a single separator and by converting all upper case characters to lower case.
-