- All Implemented Interfaces:
Serializable,Comparable<OperatingSystem>,java.lang.constant.Constable
public enum OperatingSystem extends Enum<OperatingSystem>
Enumeration with the (supported) operating systems.
- Author:
- steiner
-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>> -
Enum Constant Summary
-
Method Summary
Modifier and Type Method Description static OperatingSystemtoOperatingSystem()Determines the operating system your application is currently running on.static OperatingSystemvalueOf(String name)Returns the enum constant of this type with the specified name.static OperatingSystem[]values()Returns an array containing the constants of this enum type, in the order they are declared.
-
Enum Constant Details
-
UNIX
Unix / Linux / BSD like operating system. -
WINDOWS
-
MAC
-
UNKNOWN
Unknown operating system.
-
-
Method Details
-
values
Returns an array containing the constants of this enum type, in the order they are declared.- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
toOperatingSystem
Determines the operating system your application is currently running on.- Returns:
- The
OperatingSystembeing detected.
-