Enum Class OptionsSchemaOntology
- All Implemented Interfaces:
Serializable, Comparable<OptionsSchemaOntology>, Constable, DescriptionAccessor, NameAccessor, TypeAccessor, org.refcodes.ontology.EnumTerm, org.refcodes.ontology.Term, org.refcodes.ontology.UnsafeConcept
public enum OptionsSchemaOntology
extends Enum<OptionsSchemaOntology>
implements org.refcodes.ontology.UnsafeConcept
-
Nested Class Summary
Nested ClassesNested classes/interfaces inherited from class Enum
Enum.EnumDesc<E>Nested classes/interfaces inherited from interface DescriptionAccessor
DescriptionAccessor.DescriptionBuilder<B>, DescriptionAccessor.DescriptionMutator, DescriptionAccessor.DescriptionPropertyNested classes/interfaces inherited from interface NameAccessor
NameAccessor.NameBuilder<B>, NameAccessor.NameMutator, NameAccessor.NamePropertyNested classes/interfaces inherited from interface TypeAccessor
TypeAccessor.TypeBuilder<T,B>, TypeAccessor.TypeMutator<T>, TypeAccessor.TypeProperty<T> -
Enum Constant Summary
Enum ConstantsEnum ConstantDescriptionThe name of the associated environment variable.The value of the according environment variable.The given (programmatically provided) name.The given (programmatically provided) value.The name of the associated JVM system property.The value of the according JVM system property.The source of the value. -
Method Summary
Modifier and TypeMethodDescriptiongetType()static OptionsSchemaOntologyReturns the enum constant of this class with the specified name.static OptionsSchemaOntology[]values()Returns an array containing the constants of this enum class, in the order they are declared.Methods inherited from class Enum
clone, compareTo, describeConstable, equals, finalize, getDeclaringClass, hashCode, name, ordinal, toString, valueOfMethods inherited from interface org.refcodes.ontology.EnumTerm
getName, nameMethods inherited from interface org.refcodes.ontology.UnsafeConcept
get, getOr, put
-
Enum Constant Details
-
SYSTEM_PROPERTY_NAME
The name of the associated JVM system property. -
SYSTEM_PROPERTY_VALUE
The value of the according JVM system property. -
ENVIRONMENT_VARIABLE_NAME
The name of the associated environment variable. -
ENVIRONMENT_VARIABLE_VALUE
The value of the according environment variable. -
PROVIDED_NAME
The given (programmatically provided) name. -
PROVIDED_VALUE
The given (programmatically provided) value. -
VALUE_SOURCE
The source of the value.
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-
getType
- Specified by:
getTypein interfaceTypeAccessor
-
getDescription
- Specified by:
getDescriptionin interfaceDescriptionAccessor
-