- All Superinterfaces:
org.refcodes.mixin.KeyAccessor<String>,org.refcodes.mixin.KeyAccessor.KeyBuilder<String,PropertyBuilder>,org.refcodes.mixin.KeyAccessor.KeyMutator<String>,org.refcodes.mixin.KeyAccessor.KeyProperty<String>
- All Known Implementing Classes:
PropertyBuilderImpl
public interface PropertyBuilder extends org.refcodes.mixin.KeyAccessor.KeyProperty<String>, org.refcodes.mixin.KeyAccessor.KeyBuilder<String,PropertyBuilder>
Converts a key to the format of a system property (camel-case) or an
environment variable (snake-case in upper-case).
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.KeyAccessor
org.refcodes.mixin.KeyAccessor.KeyBuilder<K extends Object,B extends org.refcodes.mixin.KeyAccessor.KeyBuilder<K,B>>, org.refcodes.mixin.KeyAccessor.KeyMutator<K extends Object>, org.refcodes.mixin.KeyAccessor.KeyProperty<K extends Object> -
Method Summary
Modifier and Type Method Description static StringasNormalized(String aText, char aSeparator)Normalizes the provided text.static PropertyBuilderbuild()This is a convenience method for easily instantiating the according builder.default StringgetEnvironmentVariable()Returns the according environment variable after having converted the key as ofKeyAccessor.getKey()to an environment variable.StringgetEnvironmentVariable(String aKey)Returns the according environment variable after having converted the provided key to an environment variable.default StringgetSystemProperty()Returns the according system's property after having converted the key as ofKeyAccessor.getKey()to a system property.StringgetSystemProperty(String aKey)Returns the according system's property after having converted the provided key to a system property.default StringtoEnvironmentVariable()Converts the key as ofKeyAccessor.getKey()to an environment variable.StringtoEnvironmentVariable(String aKey)Converts the provided key to an environment variable.default StringtoPath()Converts the key as ofKeyAccessor.getKey()to a path (as ofPathMap).StringtoPath(String aKey)Converts the provided key as ofKeyAccessor.getKey()to a path (as ofPathMap).default StringtoSystemProperty()Converts the key as ofKeyAccessor.getKey()to a system property.StringtoSystemProperty(String aKey)Converts the provided key to a system property.Methods inherited from interface org.refcodes.mixin.KeyAccessor
getKeyMethods inherited from interface org.refcodes.mixin.KeyAccessor.KeyBuilder
withKeyMethods inherited from interface org.refcodes.mixin.KeyAccessor.KeyMutator
setKeyMethods inherited from interface org.refcodes.mixin.KeyAccessor.KeyProperty
letKey
-
Method Details
-
toPath
Converts the key as ofKeyAccessor.getKey()to a path (as ofPathMap). A path begins with a path delimiter "/" (as ofDelimiter.PATHand with all non alphanumeric digits being replaced by the path delimiter. Any non alphanumeric sequence is truncated to a single path delimiter.- Returns:
- The path representation of the according key.
-
toPath
Converts the provided key as ofKeyAccessor.getKey()to a path (as ofPathMap). A path begins with a path delimiter "/" (as ofDelimiter.PATHand with all non alphanumeric digits being replaced by the path delimiter. Any non alphanumeric sequence is truncated to a single path delimiter.- Parameters:
aKey- The key to be converted.- Returns:
- The path representation of the according key.
-
toSystemProperty
Converts the key as ofKeyAccessor.getKey()to a system property. A system property is the camel-case version of the according key.- Returns:
- The camel-case representation of the according key.
-
toEnvironmentVariable
Converts the key as ofKeyAccessor.getKey()to an environment variable. An environment variable is the upper-case snake-case version of the according key.- Returns:
- The upper-case snake-case representation of the according key.
-
toSystemProperty
Converts the provided key to a system property. A system property is the camel-case version of the according key.- Parameters:
aKey- The key to be converted.- Returns:
- The camel-case representation of the according key.
-
toEnvironmentVariable
Converts the provided key to an environment variable. An environment variable is the upper-case snake-case version of the according key.- Parameters:
aKey- The key to be converted.- Returns:
- The upper-case snake-case representation of the according key.
-
getSystemProperty
Returns the according system's property after having converted the key as ofKeyAccessor.getKey()to a system property. A system property is the camel-case version of the according key.- Returns:
- The system's property of the camel-case representation of the according key.
-
getEnvironmentVariable
Returns the according environment variable after having converted the key as ofKeyAccessor.getKey()to an environment variable. An environment variable is the upper-case snake-case version of the according key.- Returns:
- The environment variable of the upper-case snake-case representation of the according key.
-
getSystemProperty
Returns the according system's property after having converted the provided key to a system property. A system property is the camel-case version of the according key.- Parameters:
aKey- The value of the key to be converted.- Returns:
- The system's property of the camel-case representation of the according key.
-
getEnvironmentVariable
Returns the according environment variable after having converted the provided key to an environment variable. An environment variable is the upper-case snake-case version of the according key.- Parameters:
aKey- The value of the key to be converted.- Returns:
- The environment variable of the upper-case snake-case representation of the according key.
-
build
This is a convenience method for easily instantiating the according builder.- Returns:
- an instance (using a default implementation) of this builder
-
asNormalized
Normalizes the provided text.- Parameters:
aText- The text to be normalized.aSeparator- The character to be used for normalization.- Returns:
- The normalized
String(can be null).
-