Interface Setting
- All Superinterfaces:
DescriptionAccessor, org.refcodes.ontology.EnumTerm, NameAccessor, org.refcodes.ontology.Term, TypeAccessor, org.refcodes.ontology.UnsafeConcept, org.refcodes.ontology.UnsafeTaxon
- All Known Subinterfaces:
Option
- All Known Implementing Classes:
DiagnosticOption
Setting type describes enumerations representing well known and
normalized (hierarchical) settings for subclasses of the Settings
container.
Note: By convention, the name of such an enumeration bundling related
concepts should end with the word Ontology (such as
DocumentOntology).
When used together with the Settings container, option names derived
from Enum.name() may be normalized to namespace-compatible
identifiers (e.g. DOCUMENT_ARRAY_INDEX -> document.array.index).
It allows a setting to declare additional metadata such as a description and an expected value type.
Default methods defined by this interface provide implementations whose
values are derived from the implementing enumeration's Enum.name().
Implementing types only need to override these methods when the default
inference should be customized.
A subclass of the Settings class typically defines an enumeration
implementing this interface and passes that enumeration to the (super)
invalid reference
Settings#Settings(Settings.Builder, Class)Settings.toSchema() method.
-
Nested Class Summary
Nested classes/interfaces inherited from interface DescriptionAccessor
DescriptionAccessor.DescriptionBuilder<B>, DescriptionAccessor.DescriptionMutator, DescriptionAccessor.DescriptionPropertyNested classes/interfaces inherited from interface NameAccessor
NameAccessor.NameBuilder<B>, NameAccessor.NameMutator, NameAccessor.NamePropertyNested classes/interfaces inherited from interface TypeAccessor
TypeAccessor.TypeBuilder<T,B>, TypeAccessor.TypeMutator<T>, TypeAccessor.TypeProperty<T> -
Method Summary
Methods inherited from interface DescriptionAccessor
getDescriptionMethods inherited from interface TypeAccessor
getTypeMethods inherited from interface org.refcodes.ontology.UnsafeConcept
get, getOr, putMethods inherited from interface org.refcodes.ontology.UnsafeTaxon
getName, name