Uses of Enum
org.refcodes.runtime.ConfigLocator
-
Uses of ConfigLocator in org.refcodes.runtime
Methods in org.refcodes.runtime that return ConfigLocatorModifier and TypeMethodDescriptionstatic ConfigLocatorReturns the enum constant of this type with the specified name.static ConfigLocator[]ConfigLocator.values()Returns an array containing the constants of this enum type, in the order they are declared.