Uses of Enum
org.refcodes.runtime.OperatingSystem
-
Uses of OperatingSystem in org.refcodes.runtime
Methods in org.refcodes.runtime that return OperatingSystemModifier and TypeMethodDescriptionstatic OperatingSystemOperatingSystem.toOperatingSystem()Determines the operating system your application is currently running on.static OperatingSystemReturns the enum constant of this type with the specified name.static OperatingSystem[]OperatingSystem.values()Returns an array containing the constants of this enum type, in the order they are declared.