Uses of Enum Class
org.refcodes.runtime.Shell
-
Uses of Shell in org.refcodes.runtime
Methods in org.refcodes.runtime that return ShellModifier and TypeMethodDescriptionstatic ShellShell.toShell()Tries to determine the command line interpreter (CLI) - if any - this process is running in, e.g. whether we are running in a DOS console environment or a Linux alike Shell.static ShellReturns the enum constant of this class with the specified name.static Shell[]Shell.values()Returns an array containing the constants of this enum class, in the order they are declared.