Uses of Class
org.refcodes.runtime.Shell
-
-
Uses of Shell in org.refcodes.runtime
Methods in org.refcodes.runtime that return Shell Modifier and Type Method Description static ShellShell. toShell()Tries to determine the command line interpreter (CLI) - if any - this process is running in, e.g. whether we are running in a DOS console environment or a Linux alike Shell.static ShellShell. valueOf(String name)Returns the enum constant of this type with the specified name.static Shell[]Shell. values()Returns an array containing the constants of this enum type, in the order they are declared.
-