Uses of Enum Class
org.refcodes.runtime.SystemContext
-
Uses of SystemContext in org.refcodes.runtime
Methods in org.refcodes.runtime that return SystemContextModifier and TypeMethodDescriptionstatic SystemContextReturns the enum constant of this class with the specified name.static SystemContext[]SystemContext.values()Returns an array containing the constants of this enum class, in the order they are declared.