Uses of Enum
org.refcodes.runtime.SystemContext
-
Uses of SystemContext in org.refcodes.runtime
Methods in org.refcodes.runtime that return SystemContextModifier and TypeMethodDescriptionstatic SystemContextReturns the enum constant of this type with the specified name.static SystemContext[]SystemContext.values()Returns an array containing the constants of this enum type, in the order they are declared.