Uses of Enum Class
org.refcodes.runtime.Terminal
-
Uses of Terminal in org.refcodes.runtime
Methods in org.refcodes.runtime that return TerminalModifier and TypeMethodDescriptionstatic TerminalTerminal.toTerminal()Determines the terminal your application is currently in.static TerminalReturns the enum constant of this class with the specified name.static Terminal[]Terminal.values()Returns an array containing the constants of this enum class, in the order they are declared.