Module org.refcodes.runtime
Package org.refcodes.runtime
package org.refcodes.runtime
This package contains runtime related interfaces and enumerations. Runtime
related functionality is e.g. represented by the
OperatingSystem enumeration with which to
determine the host's OS or the Shell enumeration
with which to determine the underlying shell.
The types with which this artifact's codes work usually are represented by interfaces (as of interface based programming).
-
ClassDescriptionDeclarative syntactic sugar which may be statically imported in order to allow declarative definitions for
Annotationrelated functionality.This enumeration represents configuration folder locations (of typeFile) and configuration file retrieval as of the chosen configuration mode.TheCorrelationassigns an according (as of the enumeration) Correlation-TID to the invoking process, this TID is used in log files and is part of the process's request or response pay-load in order to track process execution throughout a JVM.TheDumpBuilderassists you in inspecting the content of an object.Utility class with helpful methods for working with a system's environment variables.Enumeration with the (supported) operating systems.Retrieves the Result of the given process asString.Converts a key to the format of a system property (camel-case) or an environment variable (snake-case in upper-case).The Class ReflectionUtility.This class indicates a non existing value in the name-to-value mapping.Utility for acquiring runtime information on software systems, classes or objects.Enumeration with the (relevant) shells (command line interpreters).Describes the context within a system's environment regarding host, user and application contexts as well as the currently invoked Java runtime session.Utility for acquiring system information on the machine this process is running in.Enumeration with the (relevant) terminals as well as interpolated terminal metrics.