Uses of Package
org.refcodes.runtime

  • Class
    Description
    This enumeration represents configuration folder locations (of type File) and configuration file retrieval as of the chosen configuration mode.
    The Correlation assigns an according (as of the enumeration) Correlation-TID to the invoking process, this TID is used in log files and is part of the process's request or response pay-load in order to track process execution throughout a JVM.
    The DumpBuilder assists you in inspecting the content of an object.
    Enumeration with the (supported) operating systems.
    Converts a key to the format of a system property (camel-case) or an environment variable (snake-case in upper-case).
    This class indicates a non existing value in the name-to-value mapping.
    Enumeration with the (relevant) shells (command line interpreters).
    Describes the context within a system's environment regarding host, user and application contexts as well as the currently invoked Java runtime session.
    Enumeration with the (relevant) terminals as well as interpolated terminal metrics.