Package org.refcodes.runtime
Interface DumpBuilder
-
- All Superinterfaces:
org.refcodes.mixin.ObjectAccessor,org.refcodes.mixin.ObjectAccessor.ObjectBuilder<DumpBuilder>,org.refcodes.mixin.ObjectAccessor.ObjectMutator,org.refcodes.mixin.ObjectAccessor.ObjectProperty
- All Known Implementing Classes:
DumpBuilderImpl
public interface DumpBuilder extends org.refcodes.mixin.ObjectAccessor.ObjectProperty, org.refcodes.mixin.ObjectAccessor.ObjectBuilder<DumpBuilder>
TheDumpBuilderassists you in inspecting the content of an object. Creates aMapcontaining the dump of an object's the member variable's values, the names being the keys and the values being the member variables' values.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Default Methods Modifier and Type Method Description default java.util.Map<java.lang.String,java.lang.String>toDump()Dumps the state of the contained object (as ofObjectAccessor.ObjectMutator.setObject(Object)) into aMapwhich is returned as result.java.util.Map<java.lang.String,java.lang.String>toDump(java.lang.Object aObj)Dumps the state of the provided object into aMapwhich is returned as result.
-
-
-
Method Detail
-
toDump
default java.util.Map<java.lang.String,java.lang.String> toDump()
Dumps the state of the contained object (as ofObjectAccessor.ObjectMutator.setObject(Object)) into aMapwhich is returned as result.- Returns:
- The
Mapwith the dumped properties of the implementing instance.
-
toDump
java.util.Map<java.lang.String,java.lang.String> toDump(java.lang.Object aObj)
Dumps the state of the provided object into aMapwhich is returned as result.- Parameters:
aObj- The object for which to create the dump.- Returns:
- The
Mapwith the dumped properties of the implementing instance.
-
-