public interface DumpBuilder extends org.refcodes.mixin.ObjectAccessor.ObjectProperty, org.refcodes.mixin.ObjectAccessor.ObjectBuilder<DumpBuilder>
DumpBuilder assists you in inspecting the content of an object.
Creates a Map containing the dump of an object's the member
variable's values, the names being the keys and the values being the member
variables' values.| Modifier and Type | Method and Description |
|---|---|
default Map<String,String> |
toDump()
Dumps the state of the contained object (as of
ObjectAccessor.ObjectMutator.setObject(Object)) into a Map which is returned as
result. |
Map<String,String> |
toDump(Object aObj)
Dumps the state of the provided object into a
Map which is
returned as result. |
Copyright © 2018. All rights reserved.