org.refcodes.mixin.ObjectAccessor, org.refcodes.mixin.ObjectAccessor.ObjectBuilder<DumpBuilder>, org.refcodes.mixin.ObjectAccessor.ObjectMutator, org.refcodes.mixin.ObjectAccessor.ObjectProperty, DumpBuilderpublic class DumpBuilderImpl extends Object implements DumpBuilder
toDump(Object, Map) wit a List if visited objects
and a "nested"-counter and dig recursively into the object. Use the
Delimiter.PATH ("/") delimiter to conform with the
CanonicalMap's Properties subclass (as of refcodes-configuration
artifact).| Constructor | Description |
|---|---|
DumpBuilderImpl() |
| Modifier and Type | Method | Description |
|---|---|---|
Object |
getObject() |
|
void |
setObject(Object aObject) |
|
Map<String,String> |
toDump(Object aObj) |
Dumps the state of the provided object into a
Map which is
returned as result. |
protected static Map<String,String> |
toDump(Object aObj,
Map<String,String> aDump) |
Dumps the state of the implementing instance into the provided
Map which is returned as result. |
DumpBuilder |
withObject(Object aObject) |
toDumppublic Object getObject()
getObject in interface org.refcodes.mixin.ObjectAccessorpublic void setObject(Object aObject)
setObject in interface org.refcodes.mixin.ObjectAccessor.ObjectMutatorpublic DumpBuilder withObject(Object aObject)
withObject in interface org.refcodes.mixin.ObjectAccessor.ObjectBuilder<DumpBuilder>public Map<String,String> toDump(Object aObj)
Map which is
returned as result.toDump in interface DumpBuilderaObj - The object for which to create the dump.Map with the dumped properties of the implementing
instance.protected static Map<String,String> toDump(Object aObj, Map<String,String> aDump)
Map which is returned as result.
This default implementation uses reflection to create a basic dump.
Map properties are processed but not recursively digged into.
Existing properties are overwritten in case shadowing super-class's
properties.Copyright © 2018. All rights reserved.