Package org.refcodes.runtime
Class PropertyBuilderImpl
- java.lang.Object
-
- org.refcodes.runtime.PropertyBuilderImpl
-
- All Implemented Interfaces:
org.refcodes.mixin.KeyAccessor<java.lang.String>,org.refcodes.mixin.KeyAccessor.KeyBuilder<java.lang.String,PropertyBuilder>,org.refcodes.mixin.KeyAccessor.KeyMutator<java.lang.String>,org.refcodes.mixin.KeyAccessor.KeyProperty<java.lang.String>,PropertyBuilder
public class PropertyBuilderImpl extends java.lang.Object implements PropertyBuilder
The Class PropertyBuilderImpl.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.KeyAccessor
org.refcodes.mixin.KeyAccessor.KeyBuilder<K extends java.lang.Object,B extends org.refcodes.mixin.KeyAccessor.KeyBuilder<K,B>>, org.refcodes.mixin.KeyAccessor.KeyMutator<K extends java.lang.Object>, org.refcodes.mixin.KeyAccessor.KeyProperty<K extends java.lang.Object>
-
-
Constructor Summary
Constructors Constructor Description PropertyBuilderImpl()
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description java.lang.StringgetEnvironmentVariable(java.lang.String aKey)Returns the according environment variable after having converted the provided key to an environment variable.java.lang.StringgetKey()java.lang.StringgetSystemProperty(java.lang.String aKey)Returns the according system's property after having converted the provided key to a system property.voidsetKey(java.lang.String aKey)java.lang.StringtoEnvironmentVariable(java.lang.String aKey)Converts the provided key to an environment variable.protected static java.lang.StringtoNormalized(java.lang.String aText, char aSeparator)java.lang.StringtoPath(java.lang.String aKey)Converts the provided key as ofKeyAccessor.getKey()to a path (as ofPathMap).java.lang.StringtoSystemProperty(java.lang.String aKey)Converts the provided key to a system property.PropertyBuilderwithKey(java.lang.String aKey)-
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
Methods inherited from interface org.refcodes.runtime.PropertyBuilder
getEnvironmentVariable, getSystemProperty, toEnvironmentVariable, toPath, toSystemProperty
-
-
-
-
Method Detail
-
getKey
public java.lang.String getKey()
- Specified by:
getKeyin interfaceorg.refcodes.mixin.KeyAccessor<java.lang.String>
-
setKey
public void setKey(java.lang.String aKey)
- Specified by:
setKeyin interfaceorg.refcodes.mixin.KeyAccessor.KeyMutator<java.lang.String>
-
withKey
public PropertyBuilder withKey(java.lang.String aKey)
- Specified by:
withKeyin interfaceorg.refcodes.mixin.KeyAccessor.KeyBuilder<java.lang.String,PropertyBuilder>
-
toPath
public java.lang.String toPath(java.lang.String aKey)
Converts the provided key as ofKeyAccessor.getKey()to a path (as ofPathMap). A path begins with a path delimiter "/" (as ofDelimiter.PATHand with all non alphanumeric digits being replaced by the path delimiter. Any non alphanumeric sequence is truncated to a single path delimiter.- Specified by:
toPathin interfacePropertyBuilder- Parameters:
aKey- The key to be converted.- Returns:
- The path representation of the according key.
-
toSystemProperty
public java.lang.String toSystemProperty(java.lang.String aKey)
Converts the provided key to a system property. A system property is the camel-case version of the according key.- Specified by:
toSystemPropertyin interfacePropertyBuilder- Parameters:
aKey- The key to be converted.- Returns:
- The camel-case representation of the according key.
-
toEnvironmentVariable
public java.lang.String toEnvironmentVariable(java.lang.String aKey)
Converts the provided key to an environment variable. An environment variable is the upper-case snake-case version of the according key.- Specified by:
toEnvironmentVariablein interfacePropertyBuilder- Parameters:
aKey- The key to be converted.- Returns:
- The upper-case snake-case representation of the according key.
-
getSystemProperty
public java.lang.String getSystemProperty(java.lang.String aKey)
Returns the according system's property after having converted the provided key to a system property. A system property is the camel-case version of the according key.- Specified by:
getSystemPropertyin interfacePropertyBuilder- Parameters:
aKey- The value of the key to be converted.- Returns:
- The system's property of the camel-case representation of the according key.
-
getEnvironmentVariable
public java.lang.String getEnvironmentVariable(java.lang.String aKey)
Returns the according environment variable after having converted the provided key to an environment variable. An environment variable is the upper-case snake-case version of the according key.- Specified by:
getEnvironmentVariablein interfacePropertyBuilder- Parameters:
aKey- The value of the key to be converted.- Returns:
- The environment variable of the upper-case snake-case representation of the according key.
-
toNormalized
protected static java.lang.String toNormalized(java.lang.String aText, char aSeparator)
-
-