| Package | Description |
|---|---|
| org.refcodes.runtime |
Constants:
The
const package contains enumerations and static final interface
variables (constants) being the invariants as used by this artifact. |
| Modifier and Type | Method and Description |
|---|---|
static Terminal |
Terminal.toTerminal()
Determines the terminal your application is currently in.
|
static Terminal |
Terminal.valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static Terminal[] |
Terminal.values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
Copyright © 2017. All rights reserved.