public class RuntimePropertiesImpl extends PropertiesImpl
RuntimePropertiesImpl load the first properties file found (with
"key=value" entries) in one of several default locations determined by the
RuntimeUtility.toAppConfigDirs() method.
At the time of this writing (2015-11-12), the locations which to seek for the
first occurrence of the properties file are determined as follows:
The applications base directory (where your JAR or your classes reside) is
taken and a list of directories relative to this base directory is generated
as defined in the RuntimeConsts.CONFIG_DIR_NAMES: The actual
directories being returned (in case them exist) are as follows, relative to
your applications base directory:
RuntimeConsts.SYS_PROP_CONFIG_DIRPropertiesImpl.MutablePropertiesImpl, PropertiesImpl.PropertiesBuilderImplProperties.ClearableProperties, Properties.MutableProperties, Properties.PropertiesBuilderDictionary.ClearableDictionary<K,V>, Dictionary.MutableDictionary<K,V>Keys.ClearableKeys<K,V>, Keys.MutableKeys<K,V>_properties| Constructor and Description |
|---|
RuntimePropertiesImpl(String aPropertiesFileName)
Loads a properties file from the first folder containing such a file as
of the specification for the method
RuntimeUtility.toAppConfigDirs(). |
public RuntimePropertiesImpl(String aPropertiesFileName) throws IOException
RuntimeUtility.toAppConfigDirs().aPropertiesFileName - The filename of the properties file to load.IOException - thrown in case accessing or processing the properties
file failed.Copyright © 2016. All rights reserved.